import { AboutLoadingSkeleton } from "@/components/common/loading-skeleton";
import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import NotificationsList from "@/components/sections/notifications/notifications-list";
import PageBreadcrump from "@/components/shared/testing/page-breadcrump";
import LocomotiveScrollWrapper from "@/components/ui/locomotive-scroll-wrapper";
import { Locale } from "@/i18n/routing";
import { getLocale } from "next-intl/server";
import { Suspense } from "react";

export default async function NotificationsPage() {
	const locale = await getLocale() as Locale;

	const breadcrumbItems = [
		{
			href: "/",
			label: {
				en: "Home",
				ar: "الرئيسية",
			},
		},
		{
			href: "/notifications",
			label: {
				en: "Notifications",
				ar: "الإشعارات",
			},
		},
	];

	return (
		<LocomotiveScrollWrapper>
			<main className="block">
				<Header />
				<Suspense fallback={<AboutLoadingSkeleton locale={locale} />}>
					<PageBreadcrump
						locale={locale}
						subtitle={{
							en: "Stay Updated",
							ar: "ابق على اطلاع",
						}}
						title={{
							en: "Your Notifications",
							ar: "إشعاراتك",
						}}
						breadcrumbItems={breadcrumbItems}
						backgroundUrl="/project.png"
					/>
					<div className="px-2 sm:px-2 md:px-4 lg:px-4 xl:px-24 py-12">
						<NotificationsList />
					</div>
				</Suspense>
				<Footer />
			</main>
		</LocomotiveScrollWrapper>
	);
}
